@@ -117,6 +117,10 @@ struct ast_sip_session_media {
 	unsigned int changed;
 	/*! \brief Remote media stream label */
 	char *remote_mslabel;
+	/*! \brief Remote stream label */
+	char *remote_label;
+	/*! \brief Stream name */
+	char *stream_name;
 };
 
 /*!
@@ -219,8 +223,12 @@ struct ast_sip_session {
 	enum ast_sip_dtmf_mode dtmf;
 	/*! Initial incoming INVITE Request-URI.  NULL otherwise. */
 	pjsip_uri *request_uri;
-	/* Media statistics for negotiated RTP streams */
+	/*! Media statistics for negotiated RTP streams */
 	AST_VECTOR(, struct ast_rtp_instance_stats *) media_stats;
+	/*! Number of challenges received during outgoing requests to determine if we are in a loop */
+	unsigned int authentication_challenge_count:4;
+	/*! Originating Line Info (ANI II digits) */
+	int ani2;
 };
 
 typedef int (*ast_sip_session_request_creation_cb)(struct ast_sip_session *session, pjsip_tx_data *tdata);
